# SAMPLE R SCRIPT FOR ESTIMATING RELATIVE RISK AND RELATIVE EXTENT;

# For Region 10 workshop, Oct 18-19, 2005.;

#John Van Sickle, US EPA, Corvallis, OR. email: vansickle.john@epa.gov  ;

# In this example, we estimate relative extent of streams with Poor Total Nitrogen condition,;
  # and relative extent for Poor condition of the aquatic vertebrate MMI.;
  #In addition, we estimate the relative risk that vertebrate MMI will be also be in;
  # poor conditon whenever the Total N stressor is in poor condition;  

###########################;

# STEP 1 -- Load psurvey.analysis package;

# STEP 2 -- Input the condition-class data for stressor and response variables;
# Then examine it, and subset it if needed; 

#In R, first navigate to the working folder, which contains the 'Original data' folder;

classdata<-read.csv("R10_condclass_wgt3.csv",row.names='SITE_ID');

#various ways to look at the dataset;
#list the number of rows and columns in data set;
dim(classdata);

#look at first five rows, and all columns;
head(classdata);

#list the column names alphabetically;
sort(names(classdata));

#for our example, we will calculate relative risk of total N for the aquatic vertebrate MMI;

#look at first 10 rows, and columns containing the vert MMI condition,;
# the Total N condition, and the sampling weights;
classdata[1:10,c('VERT_COND','NTL_COND','WGT_COND')];

##########;

## create a new data set, keeping only those sites that were 'used' and have nonmissing weights;
datnew<-classdata[(classdata$USED=='Y'& !is.na(classdata$WGT_COND)),];
dim(datnew);

# Will use 'local' variance estimator, so will need lat/lon converted to equal-area projection;
#Convert lat/lon to new equal-area coordinates, and add these to the data set;
new.coords<-marinus(datnew$POPLAT_DD, datnew$POPLONG_DD);
datnew<-data.frame(datnew, xmarinus=new.coords[,'x'], ymarinus=new.coords[,'y']);
names(datnew); #check if new columns got added;
## Data setup is complete. Proceed to analyses;

###############################;

### Step 3 -- Estimate relative extents;

# Use cat.analysis function from psurvey.analysis;
# Start by setting up the several small data frames needed by cat.analysis;

#data frame to specify the sites in datnew to be used for extent estimates.;
# Will use all 294 sites in this case;
sites.ext <- data.frame(SiteID=row.names(datnew),Use=rep(TRUE,nrow(datnew))); 

#data frame to specify subpopulations.;
# In this case, do a single 'subpopulation' that includes all sites;
subpop.ext<-data.frame(SiteID=row.names(datnew),Region_10=rep('allsites', nrow(datnew)));

#data frame with design information (weights and lat/lon);

design.ext <- data.frame(siteID=row.names(datnew), stratum=datnew$STRATUM,
			wgt=datnew$WGT_COND, xcoord=datnew$xmarinus,ycoord=datnew$ymarinus);

#data frame with the class variables whose extent we wish to estimate;
data.cat.ext <- data.frame(siteID=row.names(datnew),datnew$VERT_COND,datnew$NTL_COND);
#######;
#input data frames are complete, can now execute the cat.analysis function to estimate extent;

extent.est <- cat.analysis(sites = sites.ext, subpop=subpop.ext,design = design.ext, 
      data.cat = data.cat.ext, vartype = "Local", conf = 95);
#look at result;
extent.est;
#Note 1 -- Output data frame, extent.est, has estimates , SE's and confidence bounds ;
# For percent of stream miles (.P columns);
# Output also contains estimates for total stream length (.U columns),;
# reported in the same length units as the sampling weights; 
#Note 2-- Note the different vert condition categories, ;
# including the missing data (not explicit, must infer from reduced sample size);

# Extent estimates are complete. To report the results, ;
#  can extract the rows of extent.est having category = 'Poor', and make a barplot;

barplot(extent.est$Estimate.P[extent.est$Category=='POOR'],
        ylab='Percent of total length in POOR condition',
           names.arg=c('Vertebrate MMI','Total N'));

#############################################;

### Step 4 -- ESTIMATE RELATIVE RISK (RR);

#Identify desired stressor and response variables;
#To do other pairs, just change these assignments. Subsequent code lines stay the same;
stres<-'NTL_COND';
resp<-'VERT_COND';


# RR analysis uses only those sites that are either Good or Poor for the stressor, ;
#   and at the same time, either Good or Poor for the response;

# create a new data set containing only those sites ;
# with either 'Good' or 'Poor' values for response and stressor;
dat.RR<-datnew[(match(datnew[,resp],c('POOR','GOOD'),nomatch=0)>0 & 
                match(datnew[,stres],c('POOR','GOOD'),nomatch=0)>0),]; 

#re-declare stressor and response variables as 'factors', to remove any missing-value levels;
dat.RR[,stres]<-factor(dat.RR[,stres]);
dat.RR[,resp]<-factor(dat.RR[,resp]);

# can look at selected columns of this new data set;
dat.RR[1:10,c(resp,stres,'WGT_COND')];
dim(dat.RR);

## Data setup is complete. Can now execute relrisk() function to estimate relative risk;

RR.out<-relrisk(dframe=dat.RR,response=resp,stressor=stres,
    response.levels=c("POOR","GOOD"),stressor.levels=c("POOR","GOOD"),
    xcoord='xmarinus',ycoord='ymarinus',
    wgt='WGT_COND',vartype='Local');
										
## RR.out contains results in a 'list' object;
## can display;
RR.out;

# Discuss various components. Note that weight total (total length) is less than 50% ;
  # of the total length used in the extent estimates. Why is this? ;
# Discuss cell counts;
# Also, note that the confidence limits on RR 'cover' the value of 1.0;
# That is, our RR estimate is not statistically significantly different;
# from a "No association" RR of 1.0;

#can extract desired components;

RR.estimate<-RR.out$RelRisk;

## End of RR example;


###########################;
# TIME PERMITTING;
# an example of creating a (Good,Fair,Poor) class variable from a continuous variable;

# suppose the variable NTL is a column of total N values;

NTL<-c(0,22,300,175,35,250,100,180,131); #example values;

#create a new variable containing NTL classes of condition;
NTL_COND<-ifelse(NTL>200,'POOR',ifelse(NTL<=125, "GOOD","FAIR"));

data.frame(NTL,NTL_COND); #put continuous and class data side by side to examine;
			